@@ -1,5 +1,5 @@
--- nt-sqlite, an sqlite3 database for nutratracker clients
--- Copyright (C) 2020  Shane Jaroch <nutratracker@gmail.com>
+-- ntsqlite, an sqlite3 database for nutratracker clients
+-- Copyright (C) 2018-2022  Shane Jaroch <nutratracker@gmail.com>
 --
 -- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@ CREATE TABLE version( id integer PRIMARY KEY AUTOINCREMENT, version text NOT NUL
 );
 
 -- TODO: enforce FK constraint across two DBs?
-
 --
 ---------------------------------
 -- Equations
@@ -56,19 +55,6 @@ CREATE TABLE profiles (
   FOREIGN KEY (bf_eq_id) REFERENCES bf_eqs (id) ON UPDATE CASCADE
 );
 
---
---------------------------------
--- Food costs
---------------------------------
-
-CREATE TABLE food_costs (
-  food_id integer NOT NULL,
-  profile_id integer NOT NULL,
-  cost real NOT NULL,
-  PRIMARY KEY (food_id, profile_id),
-  FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE ON DELETE CASCADE
-);
-
 --
 --------------------------------
 -- Biometrics
@@ -125,6 +111,28 @@ CREATE TABLE recipe_dat (
   FOREIGN KEY (recipe_id) REFERENCES recipes (id) ON UPDATE CASCADE
 );
 
+--
+--------------------------------
+-- Custom foods
+--------------------------------
+
+CREATE TABLE custom_foods (
+  id integer PRIMARY KEY AUTOINCREMENT,
+  created int DEFAULT (strftime ('%s', 'now')),
+  updated int DEFAULT (strftime ('%s', 'now')),
+  tagname text NOT NULL UNIQUE,
+  name text NOT NULL UNIQUE
+);
+
+CREATE TABLE cf_dat (
+  cf_id int NOT NULL,
+  nutr_id int NOT NULL, -- no FK constraining on usda :[
+  nutr_val real NOT NULL,
+  notes text,
+  PRIMARY KEY (cf_id, nutr_id),
+  FOREIGN KEY (cf_id) REFERENCES custom_foods (id) ON UPDATE CASCADE
+);
+
 --
 --------------------------------
 -- Food (and recipe) logs
@@ -144,7 +152,8 @@ CREATE TABLE food_log (
   date int DEFAULT (strftime ('%s', 'now')),
   meal_id int NOT NULL,
   food_id int NOT NULL,
-  grams real NOT NULL,
+  msre_id int NOT NULL,
+  amt real NOT NULL,
   FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE,
   FOREIGN KEY (meal_id) REFERENCES meal_name (id) ON UPDATE CASCADE
 );
@@ -164,7 +173,6 @@ CREATE TABLE recipe_log (
 );
 
 -- TODO: CREATE TABLE custom_food_log ( ... );
-
 --
 --------------------------------
 -- Custom RDAs
@@ -178,3 +186,16 @@ CREATE TABLE rda (
   FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE
 );
 
+--
+--------------------------------
+-- Food costs
+--------------------------------
+
+CREATE TABLE food_costs (
+  food_id integer NOT NULL,
+  profile_id integer NOT NULL,
+  cost real NOT NULL,
+  PRIMARY KEY (food_id, profile_id),
+  FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE ON DELETE CASCADE
+);
+
