@@ -13,7 +13,7 @@ from ntclient import NUTRA_DIR
 # TODO: init, handle when it doesn't exist yet
 # TODO: prompt to create profile if copying default `prefs.json` with PROFILE_ID: -1 (non-existent)
 PREFS_FILE = os.path.join(NUTRA_DIR, "prefs.json")
-PREFS = dict()
+PREFS = {}
 PROFILE_ID = None
 
 
@@ -23,11 +23,12 @@ def persistence_init():
     from ntclient import DEBUG  # pylint: disable=import-outside-toplevel
 
     if os.path.isfile(PREFS_FILE):
-        PREFS = json.load(open(PREFS_FILE))
+        with open(PREFS_FILE, encoding="utf-8") as file_path:
+            PREFS = json.load(file_path)
     else:
         if DEBUG:
             print("WARN: ~/.nutra/prefs.json doesn't exist, using defaults")
-        PREFS = dict()
+        PREFS = {}
 
     PROFILE_ID = PREFS.get("current_user")
     if DEBUG and not PROFILE_ID:
