@@ -3,7 +3,7 @@ import os
 import sqlite3
 
 from ntclient import NT_DB_NAME, NUTRA_DIR, __db_target_nt__
-from ntclient.persistence.sql import close_con_and_cur, sql_entries
+from ntclient.persistence.sql import _sql, version
 from ntclient.utils.exceptions import SqlConnectError, SqlInvalidVersionError
 
 
@@ -31,30 +31,10 @@ def nt_sqlite_connect(version_check=True):
 def nt_ver():
     """Gets version string for nt.sqlite database"""
     con = nt_sqlite_connect(version_check=False)
-    cur = con.cursor()
-    result = cur.execute("SELECT * FROM version;").fetchall()
-    close_con_and_cur(con, cur, commit=False)
-    return result[-1][1]
+    return version(con)
 
 
-def _sql(query, values=None, headers=False):
+def sql(query, values=None, headers=False):
     """Executes a SQL command to nt.sqlite"""
-    from ntclient import DEBUG  # pylint: disable=import-outside-toplevel
-
     con = nt_sqlite_connect()
-    cur = con.cursor()
-    # TODO: format parameterized debug queries
-    if DEBUG:
-        # sqlite3.enable_callback_tracebacks(True)
-        print("nt.sqlite: " + query)
-    # TODO: separate `entry` & `entries` entity for single vs. bulk insert?
-    if values:
-        if isinstance(values, list):
-            rows = cur.executemany(query, values)
-        else:  # tuple
-            rows = cur.execute(query, values)
-    else:
-        rows = cur.execute(query)
-    result = sql_entries(rows, headers=headers)
-    close_con_and_cur(con, cur)
-    return result
+    return _sql(con, query, db_name="nt", values=values, headers=headers)
