@@ -1,16 +1,21 @@
 """nt.sqlite functions module"""
 from ntclient.persistence import PROFILE_ID
-from ntclient.persistence.sql.nt import _sql, nt_sqlite_connect
+from ntclient.persistence.sql.nt import sql, nt_sqlite_connect
 
-# ----------------------
+
+def sql_nt_next_index(table=None):
+    """Used for previewing inserts"""
+    query = "SELECT MAX(id) FROM %s;" % table  # nosec: B608
+    return int(sql(query)[0]["MAX(id)"])
+
+
+################################################################################
 # Recipe functions
-# ----------------------
-
-
+################################################################################
 def sql_recipe(recipe_id):
     """Selects columns for recipe_id"""
     query = "SELECT * FROM recipes WHERE id=?;"
-    return _sql(query, values=(recipe_id,))
+    return sql(query, values=(recipe_id,))
 
 
 def sql_recipes():
@@ -29,7 +34,7 @@ FROM
 GROUP BY
   id;
 """
-    return _sql(query, headers=True)
+    return sql(query, headers=True)
 
 
 def sql_analyze_recipe(recipe_id):
@@ -45,31 +50,29 @@ FROM
   INNER JOIN recipe_dat ON recipe_id = id
     AND id = ?;
 """
-    return _sql(query, values=(recipe_id,))
+    return sql(query, values=(recipe_id,))
 
 
 def sql_recipe_add():
     """TODO: method for adding recipe"""
     query = """
 """
-    return _sql(query)
+    return sql(query)
 
 
-# ----------------------
+################################################################################
 # Biometric functions
-# ----------------------
-
-
+################################################################################
 def sql_biometrics():
     """Selects biometrics"""
     query = "SELECT * FROM biometrics;"
-    return _sql(query, headers=True)
+    return sql(query, headers=True)
 
 
 def sql_biometric_logs(profile_id):
     """Selects biometric logs"""
     query = "SELECT * FROM biometric_log WHERE profile_id=?"
-    return _sql(query, values=(profile_id,), headers=True)
+    return sql(query, values=(profile_id,), headers=True)
 
 
 def sql_biometric_add(bio_vals):
@@ -79,7 +82,7 @@ def sql_biometric_add(bio_vals):
 
     # TODO: finish up
     query1 = "INSERT INTO biometric_log(profile_id, tags, notes) VALUES (?, ?, ?)"
-    _sql(query1, (PROFILE_ID, "", ""))
+    sql(query1, (PROFILE_ID, "", ""))
     log_id = cur.lastrowid
     print(log_id)
     query2 = "INSERT INTO bio_log_entry(log_id, biometric_id, value) VALUES (?, ?, ?)"
