@@ -5,7 +5,7 @@ import tarfile
 import urllib.request
 
 from ntclient import NUTRA_DIR, USDA_DB_NAME, __db_target_usda__
-from ntclient.persistence.sql import close_con_and_cur, sql_entries
+from ntclient.persistence.sql import _sql, version
 from ntclient.utils.exceptions import SqlConnectError, SqlInvalidVersionError
 
 
@@ -15,21 +15,14 @@ def usda_init(yes=False):
     def input_agree():
         return input("\nAgree to USDA download, may take minutes? [Y/n] ")
 
-    # TODO: handle resource moved on Bitbucket or version mismatch due to manual overwrite?
-    url = (
-        "https://bitbucket.org/dasheenster/nutra-utils/downloads/{0}-{1}.tar.xz".format(
-            USDA_DB_NAME, __db_target_usda__
-        )
-    )
-
-    if USDA_DB_NAME not in os.listdir(NUTRA_DIR):
+    def download_extract_usda():
         if yes or input_agree().lower() == "y":
             # TODO: save with version in filename? Don't re-download tarball, just extract?
             save_path = os.path.join(NUTRA_DIR, "%s.tar.xz" % USDA_DB_NAME)
 
             # Download usda.sqlite.tar.xz
-            print("curl -L {url} -o %s.tar.xz" % USDA_DB_NAME)
-            urllib.request.urlretrieve(url, save_path)
+            print("curl -L %s -o %s.tar.xz" % (url, USDA_DB_NAME))
+            urllib.request.urlretrieve(url, save_path)  # nosec
 
             # Extract the archive
             with tarfile.open(save_path, mode="r:xz") as usda_sqlite_file:
@@ -38,16 +31,35 @@ def usda_init(yes=False):
 
             print("==> done downloading %s" % USDA_DB_NAME)
 
+    # TODO: handle resource moved on Bitbucket or version mismatch due to manual overwrite?
+    url = (
+        "https://bitbucket.org/dasheenster/nutra-utils/downloads/{0}-{1}.tar.xz".format(
+            USDA_DB_NAME, __db_target_usda__
+        )
+    )
+
+    if USDA_DB_NAME not in os.listdir(NUTRA_DIR):
+        print("INFO: usda.sqlite doesn't exist, is this a fresh install?")
+        download_extract_usda()
+    elif usda_ver() != __db_target_usda__:
+        print(
+            "INFO: usda.sqlite target [{0}] doesn't match actual [{1}], ".format(
+                __db_target_usda__, usda_ver()
+            )
+            + "static resource (no user data lost).. downloading and extracting correct version"
+        )
+        download_extract_usda()
+
     if usda_ver() != __db_target_usda__:
         raise SqlInvalidVersionError(
-            "ERROR: usda target [{0}] mismatch actual [{1}], ".format(
+            "ERROR: usda target [{0}] failed to match actual [{1}], ".format(
                 __db_target_usda__, usda_ver()
             )
             + "please contact support or try again"
         )
 
 
-def usda_sqlite_connect(verify_version=True):
+def usda_sqlite_connect(version_check=True):
     """Connects to the usda.sqlite file, or throws an exception"""
     # TODO: support as customizable env var ?
     db_path = os.path.join(NUTRA_DIR, USDA_DB_NAME)
@@ -56,7 +68,7 @@ def usda_sqlite_connect(verify_version=True):
         # con.row_factory = sqlite3.Row  # see: https://chrisostrouchov.com/post/python_sqlite/
 
         # Verify version
-        if verify_version and usda_ver() != __db_target_usda__:
+        if version_check and usda_ver() != __db_target_usda__:
             raise SqlInvalidVersionError(
                 "ERROR: usda target [{0}] mismatch actual [{1}], ".format(
                     __db_target_usda__, usda_ver()
@@ -71,22 +83,11 @@ def usda_sqlite_connect(verify_version=True):
 
 def usda_ver():
     """Gets version string for usda.sqlite database"""
-    con = usda_sqlite_connect(verify_version=False)
-    cur = con.cursor()
-    rows = cur.execute("SELECT * FROM version;").fetchall()
-    close_con_and_cur(con, cur, commit=False)
-    return rows[-1][1]
+    con = usda_sqlite_connect(version_check=False)
+    return version(con)
 
 
-def _sql(query, headers=False):
+def sql(query, values=None, headers=False, version_check=True):
     """Executes a SQL command to usda.sqlite"""
-    from ntclient import DEBUG  # pylint: disable=import-outside-toplevel
-
-    con = usda_sqlite_connect()
-    cur = con.cursor()
-    if DEBUG:
-        print("usda.sqlite: " + query)
-    rows = cur.execute(query)
-    result = sql_entries(rows, headers=headers)
-    close_con_and_cur(con, cur)
-    return result
+    con = usda_sqlite_connect(version_check=version_check)
+    return _sql(con, query, db_name="usda", values=values, headers=headers)
