@@ -1,36 +1,39 @@
 """usda.sqlite functions module"""
-from ntclient.persistence.sql.usda import _sql
-
-# ----------------------
-# USDA  functions
-# ----------------------
+from ntclient.persistence.sql.usda import sql
+from ntclient.utils import NUTR_ID_KCAL
 
 
+################################################################################
+# Basic functions
+################################################################################
 def sql_fdgrp():
     """Shows food groups"""
     query = "SELECT * FROM fdgrp;"
-    result = _sql(query)
+    result = sql(query)
     return {x[0]: x for x in result}
 
 
-def sql_food_details(food_ids):
+def sql_food_details(food_ids=None):
     """Readable human details for foods"""
-    query = "SELECT * FROM food_des WHERE id IN (%s)"
+    if food_ids is None:
+        query = "SELECT * FROM food_des;"
+        return sql(query)
+    query = "SELECT * FROM food_des WHERE id IN (%s);"
     food_ids = ",".join(str(x) for x in set(food_ids))
-    return _sql(query % food_ids)
+    return sql(query % food_ids)
 
 
-def sql_nutrients_overview():
+def sql_nutrients_overview() -> dict:
     """Shows nutrients overview"""
     query = "SELECT * FROM nutrients_overview;"
-    result = _sql(query)
+    result = sql(query)
     return {x[0]: x for x in result}
 
 
-def sql_nutrients_details():
+def sql_nutrients_details() -> list:
     """Shows nutrients 'details'"""
     query = "SELECT * FROM nutrients_overview;"
-    return _sql(query, headers=True)
+    return sql(query, headers=True)
 
 
 def sql_servings(food_ids):
@@ -49,7 +52,7 @@ WHERE
   serv.food_id IN (%s);
 """
     food_ids = ",".join(str(x) for x in set(food_ids))
-    return _sql(query % food_ids)
+    return sql(query % food_ids)
 
 
 def sql_analyze_foods(food_ids):
@@ -66,7 +69,28 @@ WHERE
   food_des.id IN (%s);
 """
     food_ids = ",".join(str(x) for x in set(food_ids))
-    return _sql(query % food_ids)
+    return sql(query % food_ids)
+
+
+################################################################################
+# Sort
+################################################################################
+def sql_sort_helper1(nutrient_id):
+    """Selects relevant bits from nut_data for sorting"""
+    query = """
+SELECT
+  food_id,
+  nutr_id,
+  nutr_val
+FROM
+  nut_data
+WHERE
+  nutr_id = %s
+  OR nutr_id = %s
+ORDER BY
+  food_id;
+"""
+    return sql(query % (NUTR_ID_KCAL, nutrient_id))
 
 
 def sql_sort_foods(nutr_id):
@@ -90,7 +114,7 @@ WHERE
 ORDER BY
   nut_data.nutr_val DESC;
 """
-    return _sql(query % nutr_id)
+    return sql(query % nutr_id)
 
 
 def sql_sort_foods_by_kcal(nutr_id):
@@ -116,4 +140,4 @@ WHERE
 ORDER BY
   (nut_data.nutr_val / kcal.nutr_val) DESC;
 """
-    return _sql(query % nutr_id)
+    return sql(query % nutr_id)
