@@ -5,11 +5,14 @@ Created on Wed Aug 12 15:14:00 2020
 
 @author: shane
 """
+import os
+import csv
 
 from tabulate import tabulate
 
 from ntclient.persistence.sql.nt.funcs import (
     sql_analyze_recipe,
+    sql_nt_next_index,
     sql_recipe,
     sql_recipes,
 )
@@ -18,7 +21,7 @@ from ntclient.persistence.sql.usda.funcs import (
     sql_food_details,
     sql_nutrients_overview,
 )
-from ntclient.utils.nutprogbar import nutprogbar
+from ntclient.core.nutprogbar import nutprogbar
 
 
 def recipes_overview():
@@ -38,7 +41,7 @@ def recipes_overview():
 
     table = tabulate(results, headers="keys", tablefmt="presto")
     print(table)
-    return results
+    return 0, results
 
 
 def recipe_overview(recipe_id):
@@ -62,7 +65,35 @@ def recipe_overview(recipe_id):
     progbars = nutprogbar(food_ids, food_analyses, nutrients)
     print(progbars)
 
-    return recipe
+    return 0, recipe
+
+
+def recipe_import(file_path):
+    """Import a recipe to SQL database"""
+
+    def extract_id_from_filename(path):
+        filename = str(os.path.basename(path))
+        if (
+            "[" in filename
+            and "]" in filename
+            and filename.index("[") < filename.index("]")
+        ):
+            # TODO: try, raise: print/warn
+            return int(filename.split("[")[1].split("]")[0])
+        return None
+
+    if os.path.isfile(file_path):
+        # TODO: better logic than this
+        recipe_id = extract_id_from_filename(file_path) or sql_nt_next_index("recipes")
+        print(recipe_id)
+        with open(file_path, encoding="utf-8") as file:
+            reader = csv.DictReader(file)
+            # headers = next(reader)
+            rows = list(reader)
+        print(rows)
+    else:  # os.path.isdir()
+        print("not implemented ;]")
+    return 1, False
 
 
 def recipe_add(name, food_amts):
@@ -83,18 +114,7 @@ def recipe_add(name, food_amts):
 
     if confirm.lower() == "y":
         print("not implemented ;]")
-
-
-def recipe_edit(recipe_id):
-    """Edit recipe in SQL database"""
-    recipe = sql_recipe(recipe_id)[0]
-
-    # TODO: use Row dict? con.row_factory = sqlite3.Row
-    print(recipe[4])
-    confirm = input("Do you wish to edit? [Y/n] ")
-
-    if confirm.lower() == "y":
-        print("not implemented ;]")
+    return 1, False
 
 
 def recipe_delete(recipe_id):
@@ -106,3 +126,4 @@ def recipe_delete(recipe_id):
 
     if confirm.lower() == "y":
         print("not implemented ;]")
+    return 1, False
